/*--------------------------------------------------------------------
 *    The GMTPLUS-system:	@(#)dat2gmtplus.c	1.2	9/12/95
 *
 *  Based on...
 *	The GMT-system:	@(#)dat2gmt.c	2.6  7/22/93
 *
 *	Copyright (c) 1991 by P. Wessel and W. H. F. Smith
 *	See README file for copying and redistribution conditions.
 *--------------------------------------------------------------------*/
/*
 * dat2gmt will read an *.dat file (created by gmt2dat), decode it
 * and create a new *.gmt file. To edit a *.gmt file, run gmt2dat
 * to make an ASCII listing, use the editor to change the contents,
 * and then run dat2gmt to create a new binary *.gmtfile.
 *
 * Author:	Paul Wessel
 * Date:	8-FEB-1988
 * Version:	2.0
 *
 *
 * GMTPlus version 03/10/95 jcm
 * Modifications made for gmtplus database system.
 *
 */

#include "gmt.h"
#include "gmtplus_mgg.h"

#define NODATA -32000
#define MEM_SIZE 50000

struct GMT_PLUS_REC *record;
struct COL_N col;

int
main (int argc, char *argv[])
{
  int rec, n_records, leg_year, time, mag, top, yr, mo, dy, hr, mi, sc, n_alloc = MEM_SIZE, conv;
  double lat, lon, grv;
  char line[512], agency[10] = "", cruise[80] = "", stime[20];
  char data[14][10];
  char time_data[20];
  FILE *fpi, *fp, *hp;
  struct GMT *gmt;
  char gmtfile[80], gmtheader[80];
  int i, col_data;
	
	if ((argc != 3) || ((fpi = fopen(argv[1], "r")) == NULL)) {
		fprintf(stderr, "usage: dat2gmtplus asciifile cruiseleg\n");
		exit(-1);
	}


    strcpy(gmtfile,argv[2]);
    strcpy(gmtheader,argv[2]);
    strcat(gmtfile,".gmtd");
    strcat(gmtheader,".gmth");
	
	if ((fp = fopen(gmtfile,"w")) == NULL) {
		fprintf(stderr,"dat2gmtplus: could not open data file %s\n",gmtfile);
		exit(-1);
	}	

	if ((hp = fopen(gmtheader,"w")) == NULL) {
		fprintf(stderr,"dat2gmtplus: could not open header file %s\n",gmtheader);
		fclose(fp);
		exit(-1);
	}

	read_gmt_master_index();	
	
	record = (struct GMT_PLUS_REC *) GMT_memory ((char *)NULL, n_alloc, sizeof (struct GMT_PLUS_REC), "dat2gmtplus");
	
	/* Read header file containing start-year, n_records and info */
	
	fgets (line, 512, fpi);
	sscanf (line, "year=%d nrec=%d agency=%s cruise=%s", &leg_year, &n_records, agency, cruise);
	gmt = gmt_init (leg_year);

	/* set up column contents */	
	fgets (line, 512, fpi);
	sscanf (line, "%s %s %s %10s%10s%10s%10s%10s%10s%10s%10s%10s%10s%10s", 
		data[0], data[1], data[2], data[3], data[4], data[5], data[6], 
		data[7], data[8], data[9], data[10], data[11], data[12], data[13]);
	col.tsec = -1;
	col.lat = -1;
	col.lon = -1;
	col.graw = -1;
	col.gfaa = -1;
	col.twtt = -1;
	col.tcor = -1;
	col.mtot = -1;
	col.manm = -1;
	col.mflt = -1;
	col.bad_flag = -1;
	for (i=0;i<6;i++)
		col.user_long[i] = -1;
	for (i=0;i<8;i++)
		col.user_short[i] = -1;
	for (col_data=0; col_data<14; col_data++) {
		if (strcmp(data[col_data],"(null)") == 0) continue;
		for (i=0;i<MAX_TYPES;i++) {
			if (strcmp(data[col_data],gmt_column_name[i]) == 0) {
				switch (i) {
					case TSEC:
						col.tsec = col_data;
						break;
					case LAT:
						col.lat = col_data;
						break;
					case LON:
						col.lon = col_data;
						break;
					case GRAW:
						col.graw = col_data;
						break;
					case TWTT:
						col.twtt = col_data;
						break;
					case TCORR:
						col.tcor = col_data;
						break;
					case GFAA:
						col.gfaa = col_data;
						break;
					case MTOT:
						col.mtot = col_data;
						break;
					case MANM:
						col.manm = col_data;
						break;
					case MFILT:
						col.mflt = col_data;
						break;
					case BAD_FLAG:
						col.bad_flag = col_data;
						break;
					case UL0:
						col.user_long[0] = col_data;
						break;
					case UL1:
						col.user_long[1] = col_data;
						break;
					case UL2:
						col.user_long[2] = col_data;
						break;
					case UL3:
						col.user_long[3] = col_data;
						break;
					case UL4:
						col.user_long[4] = col_data;
						break;
					case UL5:
						col.user_long[5] = col_data;
						break;
					case US0:
						col.user_short[0] = col_data;
						break;
					case US1:
						col.user_short[1] = col_data;
						break;
					case US2:
						col.user_short[2] = col_data;
						break;
					case US3:
						col.user_short[3] = col_data;
						break;
					case US4:
						col.user_short[4] = col_data;
						break;
					case US5:
						col.user_short[5] = col_data;
						break;
					case US6:
						col.user_short[6] = col_data;
						break;
					case US7:
						col.user_short[7] = col_data;
						break;
					default:
						break;
				}
				i = MAX_TYPES;
			}
		}  
	}

	/* read each data row and process all columns */
	rec = 0;
	while (fgets (line, 512, fpi)) {
		sscanf (line, "%s %s %s %s %s %s %s %s %s %s %s %s %s %s", 
			time_data, data[1], data[2], data[3], data[4], data[5], data[6], 
			data[7], data[8], data[9], data[10], data[11], data[12], data[13]);
		sscanf (time_data, "%d/%d/%d/%d:%d:%d", &yr, &mo, &dy, &hr, &mi, &sc);
		record[rec].ldata[col.tsec] = gmt_time (&time, yr, mo, dy, hr, mi, sc, gmt);
		sscanf(data[col.lat], "%lf", &lat);
		sscanf(data[col.lon], "%lf", &lon);
		record[rec].ldata[col.lat] = (int) (lat * 1000000.0);
		record[rec].ldata[col.lon] = (int) (lon * 1000000.0);
		if (col.graw != -1) {
			conv = sscanf(data[col.graw], "%lf", &grv);
			grv = (conv > 0 && !isnan ((double)grv)) ? (int) rint(grv * 1.0) : NODATA;
			if (col_short[col.graw]) 
				record[rec].sdata[col.graw-6] = grv;
			else
				record[rec].ldata[col.graw] = grv;
		}
		if (col.gfaa != -1) {
			conv = sscanf(data[col.gfaa], "%lf", &grv);
			grv = (conv > 0 && !isnan ((double)grv)) ? (int) rint(grv * 1.0) : NODATA;
			if (col_short[col.gfaa]) 
				record[rec].sdata[col.gfaa-6] = grv;
			else
				record[rec].ldata[col.gfaa] = grv;
		}
		if (col.twtt != -1) {
			conv = sscanf(data[col.twtt], "%lf", &grv);
			grv = (conv > 0 && !isnan ((double)grv)) ? (int) rint(grv * 1.0) : NODATA;
			if (col_short[col.twtt]) 
				record[rec].sdata[col.twtt-6] = grv;
			else
				record[rec].ldata[col.twtt] = grv;
		}
		if (col.tcor != -1) {
			conv = sscanf(data[col.tcor], "%lf", &grv);
			grv = (conv > 0 && !isnan ((double)grv)) ? (int) rint(grv * 1.0) : NODATA;
			if (col_short[col.tcor]) 
				record[rec].sdata[col.tcor-6] = grv;
			else
				record[rec].ldata[col.tcor] = grv;
		}
		if (col.mtot != -1) {
			conv = sscanf(data[col.mtot], "%lf", &grv);
			grv = (conv > 0 && !isnan ((double)grv)) ? (int) rint(grv * 1.0) : NODATA;
			if (grv != NODATA) grv -= 50000;
			if (col_short[col.mtot]) 
				record[rec].sdata[col.mtot-6] = grv;
			else
				record[rec].ldata[col.mtot] = grv;
		}
		if (col.manm != -1) {
			conv = sscanf(data[col.manm], "%lf", &grv);
			grv = (conv > 0 && !isnan ((double)grv)) ? (int) rint(grv * 1.0) : NODATA;
			if (col_short[col.manm]) 
				record[rec].sdata[col.manm-6] = grv;
			else
				record[rec].ldata[col.manm] = grv;
		}
		if (col.mflt != -1) {
			conv = sscanf(data[col.mflt], "%lf", &grv);
			grv = (conv > 0 && !isnan ((double)grv)) ? (int) rint(grv * 1.0) : NODATA;
			if (col_short[col.mflt]) 
				record[rec].sdata[col.mflt-6] = grv;
			else
				record[rec].ldata[col.mflt] = grv;
		}
		if (col.bad_flag != -1) {
			conv = sscanf(data[col.bad_flag], "%lf", &grv);
			grv = (conv > 0 && !isnan ((double)grv)) ? (int) rint(grv * 1.0) : NODATA;
			if (col_short[col.bad_flag]) 
				record[rec].sdata[col.bad_flag-6] = grv;
			else
				record[rec].ldata[col.bad_flag] = grv;
		}
		for (i=0; i<6; i++) {
			if (col.user_long[i] != -1) {
				conv = sscanf(data[col.user_long[i]], "%lf", &grv);
				grv = (conv > 0 && !isnan ((double)grv)) ? (int) rint(grv * 1.0) : NODATA;
				/* 03/08/94 jcm probably always == i, but just to be safe... */
				record[rec].ldata[col.user_long[i]] = grv;
			}
		}
		for (i=0; i<8; i++) {
			if (col.user_short[i] != -1) {
				conv = sscanf(data[col.user_short[i]], "%lf", &grv);
				grv = (conv > 0 && !isnan ((double)grv)) ? (int) rint(grv * 1.0) : NODATA;
				/* 03/08/94 jcm probably always == i, but just to be safe... */
				record[rec].sdata[col.user_short[i]-6] = grv;
			}
		}
		rec++;
		if (rec == n_alloc) {
			n_alloc += GMT_CHUNK;
			record = (struct GMT_PLUS_REC *) GMT_memory ((char *)record, n_alloc, sizeof (struct GMT_PLUS_REC), "dat2gmtplus");
		}
	}
	fclose (fpi);
	
	free ((char *)gmt);
	n_records = rec;

	/* 03/23/95 jcm Need to copy header pedigree??? */
	write_gmt_header(hp, &col, leg_year, n_records, agency, cruise, gmtfile);
	write_first_gmt_datarec(fp, &col);
	for (rec = 0; rec < n_records; rec++) {
		if (fwrite((char *)(&record[rec]), 40, 1, fp) != 1) {
			fprintf(stderr,"dat2gmtplus: Error writing data record no %d\n",rec);
			exit(-1);
		}
	}
	fclose(fp);
	fclose(hp);
	
	free ((char *)record);
	
	exit (0);
}
