c 8/20/04 Ed Stickgold - Used to replace content of
c                GMTPlus library: magfld.a
c
c 6/29/01	 added 1995 dgrf, 2000 igrf, 2000sv
c
	subroutine igrf2000(long,lat,alt,date,x,y,z,f)
c	
c calculates the interpolated (<1995) or extrapolated (>1995) main field
c and secular variation coefficients and passes these to the Malin and
c Barraclough routine to calculate the IGRF field. dgrf coefficients 
c for 1945 to 1990, igrf for 1995 and coefficients for 1995+ secular 
c variation are from NOAA, World Data Center A (e.g. Barton et al., 
c 1996, PEPI, 97: 23-26).
c
c Input:
c       date  = Required date in years and decimals of a year (A.D.)
c       alt   = height above mean sea level in km (itype = 1 assumed)
c       lat   = latitude in degrees (-90 to 90)
c       long  = east longitude in degrees (0 to 360 or -180 to 180)
c Output:
c       x     = north component of the magnetic force in nT
c       y     = east component of the magnetic force in nT
c       z     = downward component of the magnetic force in nT
c       f     = total magnetic force in nT
c
c To check the results you can run the interactive program at the NGDC
c	 http://www.ngdc.noaa.gov/cgi-bin/seg/gmag/fldsnth1.pl
c
c
c 6/29/01	added 1995 dgrf, 2000 igrf, 2000sv
c
        real gh(120),sv(120),long,lat,alt,date,colat
        real dgrf45(120),dgrf50(120),dgrf55(120),dgrf60(120)
        real dgrf65(120),dgrf70(120),dgrf75(120),dgrf80(120)
        real dgrf85(120),dgrf90(120),dgrf95(120),igrf00(120)
        real sv00(120)

	data dgrf45/ -30594., -2285., 5810., -1244., 2990., -1702. , 
     1     1578. ,    477. ,   1282. ,  -1834. ,   -499. ,   1255. , 
     1      186. ,    913. ,    -11. ,    944. ,    776. ,    144. , 
     1      544. ,   -276. ,   -421. ,    -55. ,    304. ,   -178. , 
     1     -253. ,    346. ,    -12. ,    194. ,     95. ,    -20. , 
     1      -67. ,   -142. ,   -119. ,    -82. ,     82. ,     59. , 
     1       57. ,      6. ,      6. ,    100. ,   -246. ,     16. , 
     1      -25. ,     -9. ,     21. ,    -16. ,   -104. ,    -39. , 
     1       70. ,    -40. ,    -45. ,      0. ,    -18. ,      0. , 
     1        2. ,    -29. ,      6. ,    -10. ,     28. ,     15. , 
     1      -17. ,     29. ,    -22. ,     13. ,      7. ,     12. , 
     1       -8. ,    -21. ,     -5. ,    -12. ,      9. ,     -7. , 
     1        7. ,      2. ,    -10. ,     18. ,      7. ,      3. , 
     1        2. ,    -11. ,      5. ,    -21. ,    -27. ,      1. , 
     1       17. ,    -11. ,     29. ,      3. ,     -9. ,     16. , 
     1        4. ,     -3. ,      9. ,     -4. ,      6. ,     -3. , 
     1        1. ,     -4. ,      8. ,     -3. ,     11. ,      5. , 
     1        1. ,      1. ,      2. ,    -20. ,     -5. ,     -1. , 
     1       -1. ,     -6. ,      8. ,      6. ,     -1. ,     -4. , 
     1       -3. ,     -2. ,      5. ,      0. ,     -2. ,     -2. / 

 	data dgrf50 /-30554. , -2250., 5815., -1341., 2998.,-1810. , 
     1     1576. ,    381. ,   1297. ,  -1889. ,   -476. ,   1274. , 
     1      206. ,    896. ,    -46. ,    954. ,    792. ,    136. , 
     1      528. ,   -278. ,   -408. ,    -37. ,    303. ,   -210. , 
     1     -240. ,    349. ,      3. ,    211. ,    103. ,    -20. , 
     1      -87. ,   -147. ,   -122. ,    -76. ,     80. ,     54. , 
     1       57. ,     -1. ,      4. ,     99. ,   -247. ,     33. , 
     1      -16. ,    -12. ,     12. ,    -12. ,   -105. ,    -30. , 
     1       65. ,    -55. ,    -35. ,      2. ,    -17. ,      1. , 
     1        0. ,    -40. ,     10. ,     -7. ,     36. ,      5. , 
     1      -18. ,     19. ,    -16. ,     22. ,     15. ,      5. , 
     1       -4. ,    -22. ,     -1. ,      0. ,     11. ,    -21. , 
     1       15. ,     -8. ,    -13. ,     17. ,      5. ,     -4. , 
     1       -1. ,    -17. ,      3. ,     -7. ,    -24. ,     -1. , 
     1       19. ,    -25. ,     12. ,     10. ,      2. ,      5. , 
     1        2. ,     -5. ,      8. ,     -2. ,      8. ,      3. , 
     1      -11. ,      8. ,     -7. ,     -8. ,      4. ,     13. , 
     1       -1. ,     -2. ,     13. ,    -10. ,     -4. ,      2. , 
     1        4. ,     -3. ,     12. ,      6. ,      3. ,     -3. , 
     1        2. ,      6. ,     10. ,     11. ,      3. ,      8. / 

	data dgrf55 / -30500., -2215., 5820., -1440., 3003., -1898., 
     1     1581. ,    291. ,   1302. ,  -1944. ,   -462. ,   1288. , 
     1      216. ,    882. ,    -83. ,    958. ,    796. ,    133. , 
     1      510. ,   -274. ,   -397. ,    -23. ,    290. ,   -230. , 
     1     -229. ,    360. ,     15. ,    230. ,    110. ,    -23. , 
     1      -98. ,   -152. ,   -121. ,    -69. ,     78. ,     47. , 
     1       57. ,     -9. ,      3. ,     96. ,   -247. ,     48. , 
     1       -8. ,    -16. ,      7. ,    -12. ,   -107. ,    -24. , 
     1       65. ,    -56. ,    -50. ,      2. ,    -24. ,     10. , 
     1       -4. ,    -32. ,      8. ,    -11. ,     28. ,      9. , 
     1      -20. ,     18. ,    -18. ,     11. ,      9. ,     10. , 
     1       -6. ,    -15. ,    -14. ,      5. ,      6. ,    -23. , 
     1       10. ,      3. ,     -7. ,     23. ,      6. ,     -4. , 
     1        9. ,    -13. ,      4. ,      9. ,    -11. ,     -4. , 
     1       12. ,     -5. ,      7. ,      2. ,      6. ,      4. , 
     1       -2. ,      1. ,     10. ,      2. ,      7. ,      2. , 
     1       -6. ,      5. ,      5. ,     -3. ,     -5. ,     -4. , 
     1       -1. ,      0. ,      2. ,     -8. ,     -3. ,     -2. , 
     1        7. ,     -4. ,      4. ,      1. ,     -2. ,     -3. , 
     1        6. ,      7. ,     -2. ,     -1. ,      0. ,     -3. / 

	data dgrf60 / -30421., -2169., 5791., -1555., 3002., -1967., 
     1     1590. ,    206. ,   1302. ,  -1992. ,   -414. ,   1289. , 
     1      224. ,    878. ,   -130. ,    957. ,    800. ,    135. , 
     1      504. ,   -278. ,   -394. ,      3. ,    269. ,   -255. , 
     1     -222. ,    362. ,     16. ,    242. ,    125. ,    -26. , 
     1     -117. ,   -156. ,   -114. ,    -63. ,     81. ,     46. , 
     1       58. ,    -10. ,      1. ,     99. ,   -237. ,     60. , 
     1       -1. ,    -20. ,     -2. ,    -11. ,   -113. ,    -17. , 
     1       67. ,    -56. ,    -55. ,      5. ,    -28. ,     15. , 
     1       -6. ,    -32. ,      7. ,     -7. ,     23. ,     17. , 
     1      -18. ,      8. ,    -17. ,     15. ,      6. ,     11. , 
     1       -4. ,    -14. ,    -11. ,      7. ,      2. ,    -18. , 
     1       10. ,      4. ,     -5. ,     23. ,     10. ,      1. , 
     1        8. ,    -20. ,      4. ,      6. ,    -18. ,      0. , 
     1       12. ,     -9. ,      2. ,      1. ,      0. ,      4. , 
     1       -3. ,     -1. ,      9. ,     -2. ,      8. ,      3. , 
     1        0. ,     -1. ,      5. ,      1. ,     -3. ,      4. , 
     1        4. ,      1. ,      0. ,      0. ,     -1. ,      2. , 
     1        4. ,     -5. ,      6. ,      1. ,      1. ,     -1. , 
     1       -1. ,      6. ,      2. ,      0. ,      0. ,     -7. / 

	data dgrf65 / -30334., -2119., 5776., -1662., 2997., -2016., 
     1     1594. ,    114. ,   1297. ,  -2038. ,   -404. ,   1292. , 
     1      240. ,    856. ,   -165. ,    957. ,    804. ,    148. , 
     1      479. ,   -269. ,   -390. ,     13. ,    252. ,   -269. , 
     1     -219. ,    358. ,     19. ,    254. ,    128. ,    -31. , 
     1     -126. ,   -157. ,    -97. ,    -62. ,     81. ,     45. , 
     1       61. ,    -11. ,      8. ,    100. ,   -228. ,     68. , 
     1        4. ,    -32. ,      1. ,     -8. ,   -111. ,     -7. , 
     1       75. ,    -57. ,    -61. ,      4. ,    -27. ,     13. , 
     1       -2. ,    -26. ,      6. ,     -6. ,     26. ,     13. , 
     1      -23. ,      1. ,    -12. ,     13. ,      5. ,      7. , 
     1       -4. ,    -12. ,    -14. ,      9. ,      0. ,    -16. , 
     1        8. ,      4. ,     -1. ,     24. ,     11. ,     -3. , 
     1        4. ,    -17. ,      8. ,     10. ,    -22. ,      2. , 
     1       15. ,    -13. ,      7. ,     10. ,     -4. ,     -1. , 
     1       -5. ,     -1. ,     10. ,      5. ,     10. ,      1. , 
     1       -4. ,     -2. ,      1. ,     -2. ,     -3. ,      2. , 
     1        2. ,      1. ,     -5. ,      2. ,     -2. ,      6. , 
     1        4. ,     -4. ,      4. ,      0. ,      0. ,     -2. , 
     1        2. ,      3. ,      2. ,      0. ,      0. ,     -6. /

	data dgrf70 / -30220., -2068., 5737., -1781., 3000., -2047., 
     1     1611. ,     25. ,   1287. ,  -2091. ,   -366. ,   1278. , 
     1      251. ,    838. ,   -196. ,    952. ,    800. ,    167. , 
     1      461. ,   -266. ,   -395. ,     26. ,    234. ,   -279. , 
     1     -216. ,    359. ,     26. ,    262. ,    139. ,    -42. , 
     1     -139. ,   -160. ,    -91. ,    -56. ,     83. ,     43. , 
     1       64. ,    -12. ,     15. ,    100. ,   -212. ,     72. , 
     1        2. ,    -37. ,      3. ,     -6. ,   -112. ,      1. , 
     1       72. ,    -57. ,    -70. ,      1. ,    -27. ,     14. , 
     1       -4. ,    -22. ,      8. ,     -2. ,     23. ,     13. , 
     1      -23. ,     -2. ,    -11. ,     14. ,      6. ,      7. , 
     1       -2. ,    -15. ,    -13. ,      6. ,     -3. ,    -17. , 
     1        5. ,      6. ,      0. ,     21. ,     11. ,     -6. , 
     1        3. ,    -16. ,      8. ,     10. ,    -21. ,      2. , 
     1       16. ,    -12. ,      6. ,     10. ,     -4. ,     -1. , 
     1       -5. ,      0. ,     10. ,      3. ,     11. ,      1. , 
     1       -2. ,     -1. ,      1. ,     -3. ,     -3. ,      1. , 
     1        2. ,      1. ,     -5. ,      3. ,     -1. ,      4. , 
     1        6. ,     -4. ,      4. ,      0. ,      1. ,     -1. , 
     1        0. ,      3. ,      3. ,      1. ,     -1. ,     -4. / 

	data dgrf75 / -30100., -2013., 5675., -1902., 3010., -2067., 
     1     1632. ,    -68. ,   1276. ,  -2144. ,   -333. ,   1260. , 
     1      262. ,    830. ,   -223. ,    946. ,    791. ,    191. , 
     1      438. ,   -265. ,   -405. ,     39. ,    216. ,   -288. , 
     1     -218. ,    356. ,     31. ,    264. ,    148. ,    -59. , 
     1     -152. ,   -159. ,    -83. ,    -49. ,     88. ,     45. , 
     1       66. ,    -13. ,     28. ,     99. ,   -198. ,     75. , 
     1        1. ,    -41. ,      6. ,     -4. ,   -111. ,     11. , 
     1       71. ,    -56. ,    -77. ,      1. ,    -26. ,     16. , 
     1       -5. ,    -14. ,     10. ,      0. ,     22. ,     12. , 
     1      -23. ,     -5. ,    -12. ,     14. ,      6. ,      6. , 
     1       -1. ,    -16. ,    -12. ,      4. ,     -8. ,    -19. , 
     1        4. ,      6. ,      0. ,     18. ,     10. ,    -10. , 
     1        1. ,    -17. ,      7. ,     10. ,    -21. ,      2. , 
     1       16. ,    -12. ,      7. ,     10. ,     -4. ,     -1. , 
     1       -5. ,     -1. ,     10. ,      4. ,     11. ,      1. , 
     1       -3. ,     -2. ,      1. ,     -3. ,     -3. ,      1. , 
     1        2. ,      1. ,     -5. ,      3. ,     -2. ,      4. , 
     1        5. ,     -4. ,      4. ,     -1. ,      1. ,     -1. , 
     1        0. ,      3. ,      3. ,      1. ,     -1. ,     -5. / 

	data dgrf80 / -29992., -1956., 5604., -1997., 3027., -2129., 
     1     1663. ,   -200. ,   1281. ,  -2180. ,   -336. ,   1251. , 
     1      271. ,    833. ,   -252. ,    938. ,    782. ,    212. , 
     1      398. ,   -257. ,   -419. ,     53. ,    199. ,   -297. , 
     1     -218. ,    357. ,     46. ,    261. ,    150. ,    -74. , 
     1     -151. ,   -162. ,    -78. ,    -48. ,     92. ,     48. , 
     1       66. ,    -15. ,     42. ,     93. ,   -192. ,     71. , 
     1        4. ,    -43. ,     14. ,     -2. ,   -108. ,     17. , 
     1       72. ,    -59. ,    -82. ,      2. ,    -27. ,     21. , 
     1       -5. ,    -12. ,     16. ,      1. ,     18. ,     11. , 
     1      -23. ,     -2. ,    -10. ,     18. ,      6. ,      7. , 
     1        0. ,    -18. ,    -11. ,      4. ,     -7. ,    -22. , 
     1        4. ,      9. ,      3. ,     16. ,      6. ,    -13. , 
     1       -1. ,    -15. ,      5. ,     10. ,    -21. ,      1. , 
     1       16. ,    -12. ,      9. ,      9. ,     -5. ,     -3. , 
     1       -6. ,     -1. ,      9. ,      7. ,     10. ,      2. , 
     1       -6. ,     -5. ,      2. ,     -4. ,     -4. ,      1. , 
     1        2. ,      0. ,     -5. ,      3. ,     -2. ,      6. , 
     1        5. ,     -4. ,      3. ,      0. ,      1. ,     -1. , 
     1        2. ,      4. ,      3. ,      0. ,      0. ,     -6. / 

	data dgrf85 / -29873., -1905., 5500., -2072., 3044., -2197., 
     1     1687. ,   -306. ,   1296. ,  -2208. ,   -310. ,   1247. , 
     1      284. ,    829. ,   -297. ,    936. ,    780. ,    232. , 
     1      361. ,   -249. ,   -424. ,     69. ,    170. ,   -297. , 
     1     -214. ,    355. ,     47. ,    253. ,    150. ,    -93. , 
     1     -154. ,   -164. ,    -75. ,    -46. ,     95. ,     53. , 
     1       65. ,    -16. ,     51. ,     88. ,   -185. ,     69. , 
     1        4. ,    -48. ,     16. ,     -1. ,   -102. ,     21. , 
     1       74. ,    -62. ,    -83. ,      3. ,    -27. ,     24. , 
     1       -2. ,     -6. ,     20. ,      4. ,     17. ,     10. , 
     1      -23. ,      0. ,     -7. ,     21. ,      6. ,      8. , 
     1        0. ,    -19. ,    -11. ,      5. ,     -9. ,    -23. , 
     1        4. ,     11. ,      4. ,     14. ,      4. ,    -15. , 
     1       -4. ,    -11. ,      5. ,     10. ,    -21. ,      1. , 
     1       15. ,    -12. ,      9. ,      9. ,     -6. ,     -3. , 
     1       -6. ,     -1. ,      9. ,      7. ,      9. ,      1. , 
     1       -7. ,     -5. ,      2. ,     -4. ,     -4. ,      1. , 
     1        3. ,      0. ,     -5. ,      3. ,     -2. ,      6. , 
     1        5. ,     -4. ,      3. ,      0. ,      1. ,     -1. , 
     1        2. ,      4. ,      3. ,      0. ,      0. ,     -6. / 

	data dgrf90 / -29775., -1848., 5406., -2131., 3059., -2279., 
     1     1686. ,   -373. ,   1314. ,  -2239. ,   -284. ,   1248. , 
     1      293. ,    802. ,   -352. ,    939. ,    780. ,    247. , 
     1      325. ,   -240. ,   -423. ,     84. ,    141. ,   -299. , 
     1     -214. ,    353. ,     46. ,    245. ,    154. ,   -109. , 
     1     -153. ,   -165. ,    -69. ,    -36. ,     97. ,     61. , 
     1       65. ,    -16. ,     59. ,     82. ,   -178. ,     69. , 
     1        3. ,    -52. ,     18. ,      1. ,    -96. ,     24. , 
     1       77. ,    -64. ,    -80. ,      2. ,    -26. ,     26. , 
     1        0. ,     -1. ,     21. ,      5. ,     17. ,      9. , 
     1      -23. ,      0. ,     -4. ,     23. ,      5. ,     10. , 
     1       -1. ,    -19. ,    -10. ,      6. ,    -12. ,    -22. , 
     1        3. ,     12. ,      4. ,     12. ,      2. ,    -16. , 
     1       -6. ,    -10. ,      4. ,      9. ,    -20. ,      1. , 
     1       15. ,    -12. ,     11. ,      9. ,     -7. ,     -4. , 
     1       -7. ,     -2. ,      9. ,      7. ,      8. ,      1. , 
     1       -7. ,     -6. ,      2. ,     -3. ,     -4. ,      2. , 
     1        2. ,      1. ,     -5. ,      3. ,     -2. ,      6. , 
     1        4. ,     -4. ,      3. ,      0. ,      1. ,     -2. , 
     1        3. ,      3. ,      3. ,     -1. ,      0. ,     -6. /

	data dgrf95 / -29682., -1789., 5318., -2197., 3074., -2356.,
     1    1685. ,   -425. ,   1329. ,  -2268. ,   -263. ,   1249. ,
     1     302. ,    769. ,   -406. ,    941. ,    782. ,    262. ,
     1     291. ,   -232. ,   -421. ,     98. ,    116. ,   -301. ,
     1    -210. ,    352. ,     44. ,    237. ,    157. ,   -122. ,
     1    -152. ,   -167. ,    -64. ,    -26. ,     99. ,     66. ,
     1      64. ,    -16. ,     65. ,     77. ,   -172. ,     67. ,
     1       2. ,    -57. ,     17. ,      4. ,    -94. ,     28. ,
     1      78. ,    -67. ,    -77. ,      1. ,    -25. ,     29. ,
     1       3. ,      4. ,     22. ,      8. ,     16. ,     10. ,
     1     -23. ,     -2. ,     -3. ,     24. ,      4. ,     12. ,
     1      -1. ,    -20. ,     -9. ,      7. ,    -14. ,    -21. ,
     1       4. ,     12. ,      5. ,     10. ,      0. ,    -17. ,
     1      -7. ,    -10. ,      4. ,      9. ,    -19. ,      1. ,
     1      15. ,    -12. ,     11. ,      9. ,     -7. ,     -4. ,
     1      -7. ,     -2. ,      9. ,      7. ,      7. ,      0. ,
     1      -8. ,     -6. ,      1. ,     -3. ,     -4. ,      2. ,
     1       2. ,      1. ,     -5. ,      3. ,     -2. ,      6. ,
     1       4. ,     -4. ,      3. ,      0. ,      1. ,     -2. ,
     1       3. ,      3. ,      3. ,     -1. ,      0. ,     -6. /

	data igrf00 / -29615., -1728., 5186., -2267., 3072., -2478.,
     1     1672. ,   -458. ,   1341. ,  -2290. ,   -227. ,   1253. ,
     1      296. ,    715. ,   -492. ,    935. ,    787. ,    272. ,
     1      251. ,   -232. ,   -405. ,    119. ,    110. ,   -304. ,
     1     -217. ,    351. ,     44. ,    222. ,    172. ,   -131. ,
     1     -134. ,   -169. ,    -40. ,    -12. ,    107. ,     72. ,
     1       68. ,    -17. ,     74. ,     64. ,   -161. ,     65. ,
     1       -5. ,    -61. ,     17. ,      1. ,    -91. ,     44. ,
     1       79. ,    -74. ,    -65. ,      0. ,    -24. ,     33. ,
     1        6. ,      9. ,     24. ,      7. ,     15. ,      8. ,
     1      -25. ,     -2. ,     -6. ,     25. ,      6. ,     12. ,
     1       -9. ,    -22. ,     -8. ,      8. ,    -17. ,    -21. ,
     1        9. ,     15. ,      7. ,      9. ,     -8. ,    -16. ,
     1       -7. ,     -3. ,      5. ,      9. ,    -20. ,      3. ,
     1       13. ,     -8. ,     12. ,      6. ,     -6. ,     -9. ,
     1       -8. ,     -2. ,      9. ,      9. ,      4. ,     -4. ,
     1       -8. ,     -8. ,      5. ,     -2. ,     -6. ,      1. ,
     1        2. ,      0. ,     -3. ,      4. ,      0. ,      5. ,
     1        4. ,     -6. ,      1. ,     -1. ,      2. ,     -3. ,
     1        4. ,      0. ,      0. ,     -2. ,     -1. ,     -8. /

	data sv00 /    14.6,   10.7,  -22.5,  -12.4,    1.1,  -20.6,
     1      -1.1,    -9.6,     0.7,    -5.4,     6.0,     0.9,
     1      -0.1,    -7.7,   -14.2,    -1.3,     1.6,     2.1,
     1      -7.3,     1.3,     2.9,     5.0,    -3.2,     0.3,
     1       0.0,    -0.7,    -0.1,    -2.1,     0.6,    -2.8,
     1       1.7,    -0.8,     1.9,     2.5,     0.1,     1.0,
     1      -0.4,    -0.2,     0.9,    -1.4,     2.0,     0.0,
     1      -0.6,    -0.8,    -0.3,     0.0,     1.2,     0.9,
     1      -0.4,    -0.4,     1.1,    -0.3,     0.0,     1.1,
     1       0.3,     1.1,    -0.1,    -0.2,    -0.6,     0.6,
     1      -0.7,    -0.9,     0.2,    -0.3,     0.2,     0.1,
     1      -0.3,     0.0,     0.4,     0.0,    -1.0,     0.3,
     1       0.3,     0.6,    -0.5,    -0.4,    -0.7,     0.3,
     1      -0.4,     0.7,     0.0,     0.0,     0.0,     0.0,
     1       0.0,     0.0,     0.0,     0.0,     0.0,     0.0,
     1       0.0,     0.0,     0.0,     0.0,     0.0,     0.0,
     1       0.0,     0.0,     0.0,     0.0,     0.0,     0.0,
     1       0.0,     0.0,     0.0,     0.0,     0.0,     0.0,
     1       0.0,     0.0,     0.0,     0.0,     0.0,     0.0,
     1       0.0,     0.0,     0.0,     0.0,     0.0,     0.0 /

c***********************************************************************

	colat = 90.-lat		  ! convert to colatitude for MB routine
	if(long.LT.0) long=long+360. ! ensure all positive E longitudes
	itype = 1		  ! use geodetic coordinates
	
	if (date.LT.1945) then
	  write(*,*) ' field model available only after 1945 '
	  stop
	elseif (date.LT.1950) then
	  do 20 i=1,120
		gh(i)=dgrf45(i)
		sv(i)=(dgrf50(i)-dgrf45(i))/5.
20	  continue
	  call magsyn(gh,sv,1945.,date,itype,alt,colat,long,x,y,z,f)
	elseif (date.LT.1955) then
	  do 21 i=1,120
		gh(i)=dgrf50(i)
		sv(i)=(dgrf55(i)-dgrf50(i))/5.
21	  continue
	  call magsyn(gh,sv,1950.,date,itype,alt,colat,long,x,y,z,f)
	elseif (date.LT.1960) then
	  do 22 i=1,120
		gh(i)=dgrf55(i)
		sv(i)=(dgrf60(i)-dgrf55(i))/5.
22	  continue
	  call magsyn(gh,sv,1955.,date,itype,alt,colat,long,x,y,z,f)
	elseif (date.LT.1965) then
	  do 23 i=1,120
		gh(i)=dgrf60(i)
		sv(i)=(dgrf65(i)-dgrf60(i))/5.
23	  continue
	  call magsyn(gh,sv,1960.,date,itype,alt,colat,long,x,y,z,f)
	elseif (date.LT.1970) then
	  do 24 i=1,120
		gh(i)=dgrf65(i)
		sv(i)=(dgrf70(i)-dgrf65(i))/5.
24	  continue
	  call magsyn(gh,sv,1965.,date,itype,alt,colat,long,x,y,z,f)
	elseif (date.LT.1975) then
	  do 25 i=1,120
		gh(i)=dgrf70(i)
		sv(i)=(dgrf75(i)-dgrf70(i))/5.
25	  continue
	  call magsyn(gh,sv,1970.,date,itype,alt,colat,long,x,y,z,f)
	elseif (date.LT.1980) then
	  do 26 i=1,120
		gh(i)=dgrf75(i)
		sv(i)=(dgrf80(i)-dgrf75(i))/5.
26	  continue
	  call magsyn(gh,sv,1975.,date,itype,alt,colat,long,x,y,z,f)
	elseif (date.LT.1985) then
	  do 27 i=1,120
		gh(i)=dgrf80(i)
		sv(i)=(dgrf85(i)-dgrf80(i))/5.
27	  continue
	  call magsyn(gh,sv,1980.,date,itype,alt,colat,long,x,y,z,f)
	elseif (date.LT.1990) then
	  do 28 i=1,120
		gh(i)=dgrf85(i)
		sv(i)=(dgrf90(i)-dgrf85(i))/5.
28	  continue
	  call magsyn(gh,sv,1985.,date,itype,alt,colat,long,x,y,z,f)
	elseif (date.LT.1995) then
	  do 29 i=1,120
		gh(i)=dgrf90(i)
		sv(i)=(dgrf95(i)-dgrf90(i))/5.
29	  continue
	  call magsyn(gh,sv,1990.,date,itype,alt,colat,long,x,y,z,f)
	elseif (date.LT.2000) then
	  do 30 i=1,120
		gh(i)=dgrf95(i)
		sv(i)=(igrf00(i)-dgrf95(i))/5.
30	  continue
	  call magsyn(gh,sv,1995.,date,itype,alt,colat,long,x,y,z,f)
	else
	  do 31 i=1,120
		gh(i)=igrf00(i)
		sv(i)=sv00(i)
31	  continue
	  call magsyn(gh,sv,2000.,date,itype,alt,colat,long,x,y,z,f)
	endif
	
	return
	end
	
c***********************************************************************
        subroutine magsyn(gh,sv,begin,date,itype,alt,colat,elong,
     1             x,y,z,f)
c
c Computes x, y, z, and f for a given date and position, from the
c spherical harmonic coeifficients of the International Geomagnetic
c Reference Field (IGRF).  From Malin and Barraclough (1981)
c Computers and Geosciences, V.7, 401-405.
c
c Input:
c       date  = Required date in years and decimals of a year (A.D.)
c       itype = 1, if geodetic coordinates are used, 2 if geocentric
c       alt   = height above mean sea level in km (if itype = 1)
c       alt   = radial distance from the center of earth (itype = 2)
c       colat = colatitude in degrees (0 to 180)
c       elong = east longitude in degrees (0 to 360)
c	gh    = main field values for date (calc. in igrf subroutine)
c	sv    = secular variation coefficients (calc. in igrf sub)
c	begin = date of dgrf (or igrf) field prior to required date
c
c Output:
c       x     - north component of the magnetic force in nT
c       y     - east component of the magnetic force in nT
c       z     - downward component of the magnetic force in nT
c       f     - total magnetic force in nT
c
c	NB: the coordinate system for x,y, and z is the same as that
c     	specified by itype.
c
c Modified 4/9/97 to use DGRFs from 1945 to 1990, 1995 IGRF and sv 
c coefficient for extrapolation beyond 1995. Coefficients from Barton
c et al. PEPI, 97: 23-26 (1996), via web site for NOAA, World Data 
c Center A. Modified to use degree and order 10 as per notes in Malin
c and Barraclough (1981). igrf subroutine calculates the proper main 
c field and secular variation coefficients (interpolated between
c dgrf values or extrapolated from 1995 sv values as appropriate).
c

        real gh(120),sv(120),p(66),q(66),cl(10),sl(10)
	real begin,date
        
c set initial values

        t = date - begin
        r = alt
		one = colat*0.0174532925
        ct = cos(one)
        st = sin(one)
		one = elong*0.0174532925
        cl(1) = cos(one)
        sl(1) = sin(one)
        x = 0.0
        y = 0.0
        z = 0.0
        cd = 1.0
        sd = 0.0
        l = 1
        ll = 0
        m = 1
        n = 0
	if(itype.eq.2) goto 1

c if required, convert from geodectic to geocentric

        a2 = 40680925.0
        b2 = 40408585.0
        one = a2 * st * st
        two = b2 * ct * ct
        three = one + two
        rho = sqrt(three)
        r = sqrt(alt*(alt+2.0*rho) + (a2*one+b2*two)/three)
        cd = (alt + rho) / r
        sd = (a2 - b2) / rho * ct * st / r
        one = ct
        ct = ct*cd - st*sd
        st  = st*cd + one*sd
		
1       ratio = 6371.2 / r
        rr = ratio * ratio

c compute Schmidt quasi-normal coefficients p and x(=q)

        p(1) = 1.0
        p(3) = st
        q(1) = 0.0
        q(3) = ct
        do 8 k=2,66
                if(n .ge. m) goto 2
                m = 0
                n = n + 1
                rr = rr * ratio
                fn = n
                gn = n - 1
2               fm = m
                if(m .ne. n) goto 3
                if(k .eq. 3) goto 4
                one = sqrt(1.0 - 0.5/fm)
                j = k - n - 1
                p(k) = one * st * p(j)
                q(k) = one * (st*q(j) + ct*p(j))
                cl(m) = cl(m-1)*cl(1) - sl(m-1)*sl(1)
                sl(m) = sl(m-1)*cl(1) + cl(m-1)*sl(1)
                goto 4
3               gm = m * m
                one = sqrt(fn*fn - gm)
                two = sqrt(gn*gn - gm) / one
                three = (fn + gn) / one
        		i = k - n
        		j = i - n + 1
       		    p(k) = three*ct*p(i) - two*p(j)
        		q(k) = three*(ct*q(i) - st*p(i)) - two*q(j)

c synthesize x, y, and z in geocentric coordinates.

4       		one = (gh(l) + sv(ll+l)*t)*rr
        		if(m .eq. 0) goto 7
                two = (gh(l+1) + sv(ll+l+1)*t)*rr
                three = one*cl(m) + two*sl(m)
                x = x + three*q(k)
                z = z - (fn + 1.0)*three*p(k)
                if(st .eq. 0.0) goto 5
                y = y + (one*sl(m) - two*cl(m))*fm*p(k)/st
				goto 6
5               y = y + (one*sl(m) - two*cl(m))*q(k)*ct
6               l = l + 2
				goto 8
7               x = x + one*q(k)
                z = z - (fn + 1.0)*one*p(k)
                l = l + 1
8 		        m = m + 1


c convert to coordinate system specified by itype

        one = x
        x = x*cd + z*sd
        z = z*cd - one*sd
        f = sqrt(x*x + y*y + z*z)

        return
        end
c***********************************************************************
